% plot_figure1.m
%
% This file plots Figure 1 of "The role of durables replacement and 
% second-hand markets in a business-cycle model"
%
% main script: "main_aggregate.m"
%
% Hyunseung Oh, Feb 2018


%% TTB plot (figure 1)

%------------- User configuration -------------%
titlename  = 'Used vehicle margin to new vehicle sales'; % name of title
ylabelname = 'Percent';     % name of y label
%----------------------------------------------%

% 1. Specify start and end date to plot for TTB plot
%------------- User configuration -------------%
sdate = 1967; % start date
edate = 2017; % end date
%----------------------------------------------%
ind     = find(date>=sdate & date<= edate); % indicator of dates to plot
date1   = date(ind);
nber1   = nber(ind);
uadm1   = uadm(ind); % used auto dealers margin
utdm1   = utdm(ind); % used truck dealers margin
nads1   = nads(ind); % new auto expenditure
ntds1   = ntds(ind); % new truck expenditure


% 1.1 Specify start and end date for calibration
%------------- User configuration -------------%
sdate_calibration = 1983; % start date
edate_calibration = 2007; % end date
%----------------------------------------------%
ind_calibration     = find(date>=sdate_calibration & date<= edate_calibration); % indicator of dates to plot
uadm_calibration   = uadm(ind_calibration);
utdm_calibration   = utdm(ind_calibration);
nads_calibration   = nads(ind_calibration);
ntds_calibration   = ntds(ind_calibration);

ua_share_calibration = sum(uadm_calibration)/sum(uadm_calibration+nads_calibration);
ut_share_calibration = sum(utdm_calibration)/sum(utdm_calibration+ntds_calibration);
u_share_calibration  = sum(uadm_calibration+utdm_calibration)/sum(uadm_calibration+nads_calibration+utdm_calibration+ntds_calibration);

disp(['Value added share of used autos (1983-2007):  ' num2str(ua_share_calibration)])
disp(['Value added share of used trucks (1983-2007): ' num2str(ut_share_calibration)])
disp(['Value added share of used autos and trucks (1983-2007): ' num2str(u_share_calibration)])

% 2. Plot ratio data with shaded recessions in the background

% 2.1. Recession indicator specification
rec_ind = nber1;
drec    = [0; diff(rec_ind)];
peak    = date1(drec == 1);
trough  = date1(drec == -1);
% if data starts in a recession, set first date as peak
if rec_ind(1) == 1 && drec(2) == 0
    peak = [date1(1); peak];
end
% if data ends in a recession, set last date as trough
if rec_ind(end) == 1 && drec(2) == 0
    trough = [trough; date1(end)];
end
num_rec = length(peak); % number of recessions in the data

% Set y-axis min and max values for plot
%------------- User configuration -------------%
ymin = 0;  % y axis minimum value
ymax = 30; % y axis maximum value
%----------------------------------------------%

% 2.2. Set rectangles for each peak trough episodes with ymin and ymax
RECx = reshape([peak peak trough trough]', 4*num_rec, 1);
RECy = [ymin; ymax];
RECy = [RECy; flipud(RECy)];
RECy = kron(ones(num_rec,1), RECy);


% 3. Plot ratio
f1 = figure; % Set figure number for display

% 3.1. Figure configuration
set(gcf, 'PaperUnits', 'inches') 
set(gcf, 'PaperOrientation', 'landscape');
papersize = get(gcf, 'PaperSize');
%------------- User configuration -------------%
%width  = 8;  % Initialize a variable for width
%height = 5;   % Initialize a variable for height
%----------------------------------------------%
bottom = (papersize(2)- height)/2;
left = (papersize(1)- width)/2;
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);


% 3.2. Fill area
%fill(RECx',RECy',[0.8 0.8 0.8],'LineStyle','none')
set(gca,'YLim',[ymin ymax],'YTickMode','auto');
hold on

% 3.3. Plot series of interest
%------------- User configuration -------------%
h1 = plot(date1, 100*(uadm1)./(nads1+uadm1)); % plot for auto
h2 = plot(date1, 100*(utdm1)./(ntds1+utdm1)); % plot for truck
%----------------------------------------------%
grid on

% 3.4. Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[min(date1) max(date1)],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth', 3, 'Color', 'k');
set(h2,'LineStyle',':', 'LineWidth', 3, 'Color', [0.6 0.6 0.6]);
legend([h1 h2],'Auto','Light Truck','Location','NorthWest');
legend boxoff
set(gca,'XTick',[date1(1):10:date1(end)]) % X tick data to plot
%title(titlename,'FontSize',12,'FontWeight','Bold','Interpreter','Latex');
ylabel(ylabelname,'FontSize',12,'FontWeight','Bold','Interpreter','Latex');
xlabel('Year','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%
box on

% 3.5. Save plot
cd Plot % in a subfolder "\Plot"
print(f1,'-dpdf', [graphname]); 
print(f1,'-depsc2', [graphname]); % not sure why not working...
cd ..

