% plot_figure2.m
%
% This file plots Figure 2 of "The role of durables replacement and 
% second-hand markets in a business-cycle model"
%
% main script: "main_aggregate.m"
%
% Hyunseung Oh, Feb 2018


%% Plot (figure 2)

%------------- User configuration -------------%
titlename  = 'Auto transactions'; % name of title
ylabelname = 'Unit change from previous year (thousands)';     % name of y label
%----------------------------------------------%

% 1. Specify start and end date to plot for TTB plot
%------------- User configuration -------------%
sdate = 1991; % start date
edate = 2014; % end date
%----------------------------------------------%
ind     = find(date>=sdate & date<= edate); % indicator of dates to plot
date1   = date(ind);
nber1   = nber(ind);
nvus1   = nvus(ind);
uvus1   = uvus(ind);

u_n_rate1 = sum(uvus1)/sum(nvus1);
disp(['used to new vehicle transactions 1991-2014 = ' num2str(u_n_rate1)])

%------------- User configuration -------------%
sdate_calibration = 1990;
edate_calibration = 2007;
%----------------------------------------------%
ind_calibration = find(date>=sdate_calibration & date<= edate_calibration); % indicator of dates to plot
nvus_calibration = nvus(ind_calibration);
uvus_calibration = uvus(ind_calibration);

u_n_rate_calibration = sum(uvus_calibration)/sum(nvus_calibration);
disp(['used to new vehicle transactions 1990-2007 = ' num2str(u_n_rate_calibration)])

% 2. Plot ratio data with shaded recessions in the background

% 2.1. Recession indicator specification
rec_ind = nber1;
drec    = [0; diff(rec_ind)];
peak    = date1(drec == 1);
trough  = date1(drec == -1);
% if data starts in a recession, set first date as peak
if rec_ind(1) == 1 & drec(2) == 0
    peak = [date1(1); peak];
end
% if data ends in a recession, set last date as trough
if rec_ind(end) == 1 & drec(2) == 0
    trough = [trough; date1(end)];
end
num_rec = length(peak); % number of recessions in the data

% Set y-axis min and max values for plot
%------------- User configuration -------------%
ymin = -5000;  % y axis minimum value
ymax = +5000; % y axis maximum value
%----------------------------------------------%

% 2.2. Set rectangles for each peak trough episodes with ymin and ymax
RECx = reshape([peak peak trough trough]', 4*num_rec, 1);
RECy = [ymin; ymax];
RECy = [RECy; flipud(RECy)];
RECy = kron(ones(num_rec,1), RECy);


% 3. Plot ratio
f2 = figure; % Set figure number for display

% 3.1. Figure configuration
set(gcf, 'PaperUnits', 'inches') 
set(gcf, 'PaperOrientation', 'landscape');
papersize = get(gcf, 'PaperSize');
%------------- User configuration -------------%
%width  = 8;  % Initialize a variable for width
%height = 5;   % Initialize a variable for height
%----------------------------------------------%
bottom = (papersize(2)- height)/2;
left = (papersize(1)- width)/2;
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);


% 3.2. Fill area
fill(RECx',RECy',[0.8 0.8 0.8],'LineStyle','none')
set(gca,'YLim',[ymin ymax],'YTickMode','auto')
hold on

% 3.3. Plot series of interest
%------------- User configuration -------------%
h0 = plot(date1(2:end), 0*date1(2:end)); % zero plot
h1 = plot(date1(2:end), diff(nvus1)); % plot for new auto
h2 = plot(date1(2:end), diff(uvus1)); % plot for used auto
%----------------------------------------------%
grid on

% 3.4. Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[min(date1(2:end)) max(date1)],'XTickMode','auto','Layer','top')
set(h0,'LineStyle','-','LineWidth', 1.0, 'Color','k');
set(h1,'LineStyle','-', 'LineWidth', 2.5, 'Color', [117,  23,  31]/255);
set(h2,'LineStyle',':', 'LineWidth', 2.5, 'Color', 'k');
legend([h1 h2],'New vehicle sales','Used vehicle sales','Location','NorthWest');
legend boxoff
set(gca,'XTick',[date1(2):2:date1(end)]) % X tick data to plot
%title(titlename,'FontSize',12,'FontWeight','Bold','Interpreter','Latex');
ylabel(ylabelname,'FontSize',12,'FontWeight','Bold','Interpreter','Latex');
xlabel('Year','FontSize',12)
%----------------------------------------------%

% 3.5. Save plot
cd Plot % in a subfolder "\Plot"
print(f2,'-dpdf', [graphname]); 
print(f2,'-depsc2', [graphname]); % not sure why not working...
cd ..




%{


%----------------------------------------------------------------
f3 = figure; % FIGURE 1b
%graphname1b = 'TTBdistribution_p1';
%----------------------------------------------------------------
xPaper  = 10;    % x-axis paper size
yPaper  = 6;  % y-axis paper size

xMargin = 1;   % left/right margins from paper borders
yMargin = 1;   % bottom/top margins from paper borders

xSize   = xPaper - 2*xMargin; % figure size on paper (width)
ySize   = yPaper - 2*yMargin; % figure size on paper (height)

set(gcf,'PaperUnits','inches') 
set(gcf,'PaperSize',[xPaper yPaper]) 
set(gcf,'PaperPosition',[xMargin yMargin xSize ySize])
set(gcf,'PaperOrientation','portrait')
%----------------------------------------------------------------

difference1 = [diff(nvus1) diff(uvus1)];

hold on;
grid on;
h1 = bar(date1(2:end),difference1,'grouped');
set(h1(1),'FaceColor',[200, 200, 200]/255)
%set(h1(2),'FaceColor',[  0,   0,   0]/255)
%set(h1(2),'FaceColor',[ 26, 118, 255]/255)
set(h1(2),'FaceColor',[117,  23,  31]/255)
set(gca,'fontsize',10);
legend([h1(1) h1(2)],'New auto transactions','Used auto transactions','Location','NorthWest')
legend boxoff
%title('Estimated TTB','FontSize',12,'FontWeight','Bold','Interpreter','Latex')
ylabel('Year by year unit change (thousands)','FontSize',10)
xlabel('Year','FontSize',12)
set(gca,'XTick',[date1(2):2:date1(end)]) % X tick data to plot
ylim([-5000 5000])
xlim([date1(2)-1 date1(end)+1])

%}