function [handle] = shade_recession1(date,rec_ind,y)
% function [handle] = shade_recession1(date,rec_ind,y)
% This function generates a plot for shaded areas on based on recession
% indicator "rec_ind"
%
% Input:
% [handle] = shade_recession1(date,rec_ind,y)
% 
% date   : horizontal axis for date vector
% rec_ind: indicator vector for recessions
% y      : time series vector
%


% Recession indicator
drec   = [0; diff(rec_ind)];
peak   = date(drec == 1);
trough = date(drec == -1);

% if data starts in a recession, set first date as peak
if rec_ind(1) == 1 & drec(2) == 0
    peak = [date(1); peak];
end
% if data ends in a recession, set last date as trough
if rec_ind(end) == 1 & drec(2) == 0
    trough = [trough; date(end)];
end
    
num_rec = length(peak);

ydiff = max(y) - min(y);
ymin = min(y) - 0.1*ydiff;
ymax = max(y) + 0.1*ydiff;

RECx = reshape([peak peak trough trough]', num_rec*4, 1);
RECy = [ymin; ymax];

RECy = [RECy; flipud(RECy)];
RECy = kron(ones(num_rec,1), RECy);


% Figure configuration
set(gcf, 'PaperUnits', 'inches') 
set(gcf, 'PaperOrientation', 'landscape');
papersize = get(gcf, 'PaperSize');
width  = 10;    % Initialize a variable for width
height = 5;      % Initialize a variable for height
bottom = (papersize(2)- height)/2;
left = (papersize(1)- width)/2;
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);


% Fill area
fill(RECx',RECy',[0.8 0.8 0.8],'LineStyle','none')

set(gca,'YLim',[ymin ymax],'YTickMode','auto')

hold on
[handle] = plot(date, y);

set(gca,'XLim',[min(date) max(date)],'XTickMode','auto','Layer','top')