function [EETA BETA DEL_D PSI_C ALPHA TAU_P TAU_Y RHO_R RHO_Z RHO_V RHO_B H K c_r EPSIL THE_C ...
    MCC MCD QQ QQR SSS DELTA RHO THE_D R PIC PID PIU KC KD HC HD C C2 XX D DN W RK PHI PSI_D MU V SSN ...
    v  zc  zd  rl  d  dnl  qql  qqrl  ssnl  c  c2  xx  dn  ssn  kc  kd  h  hc  hd  w  rk  r  qq  qqr  pic  pid  piu  mcc0  mcd  muu  b ...
    vp zcp zdp rlp dp dnlp qqlp qqrlp ssnlp cp c2p xxp dnp ssnp kcp kdp hp hcp hdp wp rkp rp qqp qqrp picp pidp piup mcc0p mcdp muup bp zz zzp]=DurRep_model_ss
% DurRep_model_ss.m 
%
% Computing the nonstochastic steady state of the model, based on 
% Schmitt-Grohe and Uribe (2004).
%
%------------------------------------------------------------------
% Model replication code for "The role of durables replacement and
% second-hand markets in a business-cycle model" 
%------------------------------------------------------------------
% Equilibrium conditions: DurRep_model.m
% Steady state computation: DurRep_model_ss.m
% Run and plot file: DurRep_model_run.m
% Supporting codes from Schmitt-Grohe and Uribe (2004): anal_deriv.m,
% gx_hx.m, ir.m, mom.m, num_eval.m, gxx_hxx.m, simu_2nd.m
%------------------------------------------------------------------
%
% December 2018, Hyunseung Oh (E-mail: hyunseungoh@gmail.com)


% set parameters
EETA  = 0.35;   % capital income share
BETA  = 0.995;  % discount factor (interest rate)
DELTA = 0.06;   % used durables depreciation rate 
PSI_C = 1;      % utility weight of nondurables
ALPHA = 0.750;   % stickiness parameter of nondurable price
TAU_P = 1.5;    % Taylor coefficient on inflation (benchmark: 1.5)
TAU_Y = 0.0;      % Taylor coefficient on output (benchmark: 0.125)
RHO_R = 0;      % Taylor smoothness (benchmark: 0.5)
RHO_Z = 0.88;   % TFP persistence 
RHO_V = 0;      % persistence of interest rate shock
RHO_B = 0.8;      % persistence of demand shock

% calibration target
XI1 = 3;        % share of nondurables and services
XI2 = 0.858;     % share of new durables 
XI3 = 0.142;     % share of used durables
rsales = 2.64;  % used car to new car sales ratio (benchmark 2.34)
H = 0.20;       % steady state hours
mkup_c = 0.20;  % steady state markup for nondurables
mkup_d = 0.20;  % steady state markup for durables

% EPSIL: coefficient related to secondary market sales
EPSIL = (XI3/(XI2+XI3)) / rsales;
% THE_C: EIS for nondurables
THE_C = (1+mkup_c)/mkup_c;

% MCC, MCD, QQ
MCC = (THE_C-1)/THE_C;           % real marginal cost of nondurables
MCD = (THE_C-1)/THE_C;           % real marginal cost of durables (since divided by Pc!!)
QQ  = (1+mkup_d)*MCD;            % relative price of durables
QQR = QQ/(QQ-EPSIL);             % relative margin of selling and buying price of durables
K = ((1/EETA)*(1/BETA-1)/MCC)^(1/(EETA-1))*H;          % fixed capital

% SSS, DELTA, RHO

RHO = 1-(EPSIL/(QQ-EPSIL))/(BETA*DELTA);
if RHO < 0
    disp('Condition [QQR < 1 + BETA*DELTA] not satisfied')
end


SSS = rsales*DELTA/(rsales*DELTA*(1-RHO) + 1 - RHO*DELTA);

% DEL_D: effective depreciation rate
DEL_D = (DELTA - ((QQR-1)/BETA)*SSS)/(1+((QQR-1)/BETA)*(1-SSS));

% THE_D
THE_D = ((1+mkup_d)/mkup_d)*( DELTA*(1-SSS*(1-RHO))/(DELTA+SSS*(1-DELTA)) );

% R, PIC, PID, PIU
R   = 1/BETA;
PIC = 1;
PID = 1;
PIU = 1;

% KC, KD, KU, HC, HD, HU
c_r = (XI1+XI3)/(XI1+XI2+XI3);  % nondurable production share
KC  = c_r*K;                    % capital for nondurables
KD  = (1-c_r)*K;                % capital for new durables
HC  = c_r*H;                    % hours for nondurables
HD  = (1-c_r)*H;                % hours for new durables

% C, XX, DN, D
XX  = KD^EETA*HD^(1-EETA);       % production of new durables
D   = XX/DEL_D;                  % stock of durables 
DN  = (DELTA+SSS*(1-DELTA))/(1+DELTA*(1-SSS)*(1-RHO))*D;
MM  = SSS*((1-DELTA)*D+DELTA*(1-RHO)*DN); % secondhand durables
C   = KC^EETA*HC^(1-EETA) - EPSIL*MM;     % household consumption of nondurables
C2  = C + EPSIL*MM;             % production of nondurables

% W, RK
W   = MCC*(1-EETA)*(K/H)^EETA;   % steady state real wage
RK  = MCC*EETA*(K/H)^(EETA-1);   % steady state real capital interest rate

% PHI: disutility weight on hours
PHI = (W/H)*(PSI_C/C);

% PSI_D: utility weight on durables
PSI_D = QQ*(D/C)*(1-(BETA*(1-RHO*DELTA)/QQR))*PSI_C;

% MU: shadow value of durable stock
MU = (PSI_D/D + BETA*(1-DELTA)*SSS*(QQ/QQR)*(PSI_C/C))/(1-BETA*(1-DELTA)*(1-SSS));

% V: steady state interest rate shock
V = 1;

% Z: steady state TFP
Z = 1;

% B: steady state demand 
B = 1;

% SSN: SSS
SSN = SSS;

% Display values
disp(['RHO   = ' num2str(RHO)])
disp(['EPSIL = ' num2str(EPSIL)])
disp(['PSI_D = ' num2str(PSI_D)])
disp(['PHI   = ' num2str(PHI)])
disp(['THE_D = ' num2str(THE_D)])
disp(['SSS   = ' num2str(SSS)])
disp(['DEL_D = ' num2str(DEL_D)])


% log steady state (original)
v   = log(V);
zc  = log(Z);
zd  = log(Z);
rl  = log(R);
d   = log(D);
dnl = log(DN);
qql = log(QQ);
qqrl= log(QQR);
ssnl= log(SSN);
c   = log(C);
c2  = log(C2);
xx  = log(XX);
dn  = log(DN);  
ssn = log(SSN);
kc  = log(KC);
kd  = log(KD);
h   = log(H);
hc  = log(HC);
hd  = log(HD);
w   = log(W);
rk  = log(RK);
r   = log(R);
qq  = log(QQ);
qqr = log(QQR);
pic = log(PIC); 
pid = log(PID);
piu = log(PIU);
mcc0 = log(MCC);
mcd = log(MCD);
muu  = log(MU);
b   = log(B);

% log future steady state
vp   = log(V);
zcp  = log(Z);
zdp  = log(Z);
rlp  = log(R);
dp   = log(D);
dnlp = log(DN);
qqlp = log(QQ);
qqrlp= log(QQR);
ssnlp= log(SSN);
cp   = log(C);
c2p  = log(C2);
xxp  = log(XX);
dnp  = log(DN);  
ssnp = log(SSN);
kcp  = log(KC);
kdp  = log(KD);
hp   = log(H);
hcp  = log(HC);
hdp  = log(HD);
wp   = log(W);
rkp  = log(RK);
rp   = log(R);
qqp  = log(QQ);
qqrp = log(QQR);
picp = log(PIC); 
pidp = log(PID);
piup = log(PIU);
mcc0p = log(MCC);
mcdp = log(MCD);
muup  = log(MU);
bp   = log(B);

zz = zc;
zzp = zz;